@@ -10,7 +10,7 @@ import asyncio as aio
 from typing import Optional, Callable
 # NDN Imports
 from ndn.app import NDNApp
-from ndn.encoding import Name, Component, InterestParam, BinaryStr, FormalName, SignaturePtrs
+from ndn.encoding import Name, Component, InterestParam, BinaryStr, FormalName, SignaturePtrs, parse_data
 from ndn.types import InterestNack, InterestTimeout, InterestCanceled, ValidationFailure
 # Custom Imports
 from .logger import SVSyncLogger
@@ -26,14 +26,18 @@ from .window import AsyncWindow
 #   to hear about other sync interests
 #   to find out about new data from other nodes.
 class SVSyncBalancer:
+    PROP_WINDOW = 5
+    PROP_INTEREST_LIFETIME = 2000
+    PROP_PACKET_FRESHNESS = 5000
     def __init__(self, app:NDNApp, groupPrefix:Name, nid:Name, table:StateTable, updateCallback:Callable, secOptions:SecurityOptions) -> None:
+        SVSyncLogger.info("SVSyncBalancer: started svsync balancer")
         self.app, self.groupPrefix, self.nid, self.table, self.updateCallback, self.secOptions, self.busy = app, groupPrefix, nid, table, updateCallback, secOptions, False
-        self.balancePrefix = self.nid + self.groupPrefix + Name.from_str("/sync")
-        self.taskWindow:AsyncWindow = AsyncWindow(5)
-        self.app.route(self.balancePrefix, need_sig_ptrs=True)(self.onStateInterest)
-        SVSyncLogger.info(f'SVSyncBalancer: started listening to {Name.to_str(self.balancePrefix)}')
-    async def balanceFromState(self, name:Name, nopck:int) -> None:
-        incoming_sv:Optional[StateVector] = await self.expressStateInterest(name, nopck)
+        self.propPrefix = self.nid + self.groupPrefix + [Component.from_str("prop")]
+        self.taskWindow = AsyncWindow(self.PROP_WINDOW)
+        self.app.route(self.propPrefix, need_sig_ptrs=True)(self.onPropInterest)
+        SVSyncLogger.info(f'SVSyncBalancer: started listening to {Name.to_str(self.propPrefix)}')
+    async def balanceFromProp(self, name:Name, pckno:int) -> None:
+        incoming_sv:Optional[StateVector] = await self.sendPropInterest(name, pckno)
         if not incoming_sv:
             return
         missingList = self.table.processStateVector(incoming_sv, oldData=True)
@@ -46,25 +50,27 @@ class SVSyncBalancer:
         self.busy = True
         name = Name.from_str(bytes(incoming_md.source).decode())
         for i in range(incoming_md.nopcks):
-            self.taskWindow.addTask(self.balanceFromState, (name, i+1))
+            self.taskWindow.addTask(self.balanceFromProp, (name, i+1))
         await self.taskWindow.gather()
         SVSyncLogger.info(f'SVSyncBalancer: nmeta {bytes(self.table.getMetaData().source).decode()} - {self.table.getMetaData().tseqno} total, {self.table.getMetaData().nopcks} pcks')
         SVSyncLogger.info(f'SVSyncBalancer: ntable {self.table.getCompleteStateVector().to_str()}')
         self.busy = False
-    def onStateInterest(self, int_name:FormalName, int_param:InterestParam, _app_param:Optional[BinaryStr], sig_ptrs:SignaturePtrs) -> None:
+    def onPropInterest(self, int_name:FormalName, int_param:InterestParam, _app_param:Optional[BinaryStr], sig_ptrs:SignaturePtrs) -> None:
         SVSyncLogger.info(f'SVSyncBalancer: received balance {Name.to_str(int_name)}')
-        aio.get_event_loop().create_task(self.onStateInterestHelper(int_name, int_param, _app_param, sig_ptrs))
-    async def onStateInterestHelper(self, int_name:FormalName, int_param:InterestParam, _app_param:Optional[BinaryStr], sig_ptrs:SignaturePtrs) -> None:
+        aio.get_event_loop().create_task(self.onPropInterestHelper(int_name, int_param, _app_param, sig_ptrs))
+    async def onPropInterestHelper(self, int_name:FormalName, int_param:InterestParam, _app_param:Optional[BinaryStr], sig_ptrs:SignaturePtrs) -> None:
         sv = bytes(self.table.getPart(Component.to_number(int_name[-1])))
         SVSyncLogger.info(f'SVSyncBalancer: sending balance {sv}')
-        self.app.put_data(int_name, content=sv, freshness_period=1000)
-    async def expressStateInterest(self, source:Name, nopck:int) -> Optional[StateVector]:
-        name:Name = source + self.groupPrefix + Name.from_str("/sync") + [Component.from_number(nopck, Component.TYPE_SEQUENCE_NUM)]
+        self.app.put_data(int_name, content=sv, signer=self.secOptions.dataSig.signer, freshness_period=self.PROP_PACKET_FRESHNESS)
+    async def sendPropInterest(self, source:Name, pckno:int) -> Optional[StateVector]:
+        name:Name = source + self.groupPrefix + [Component.from_str("prop")] + [Component.from_number(pckno, Component.TYPE_SEQUENCE_NUM)]
         try:
             SVSyncLogger.info(f'SVSyncBalancer: balancing by {Name.to_str(name)}')
-            data_name, meta_info, content = await self.app.express_interest(
-                name, must_be_fresh=True, can_be_prefix=True, lifetime=1000)
-            return StateVector(bytes(content)) if bytes(content) != b'' else None
+            _, _, _, pkt = await self.app.express_interest(
+                name, need_raw_packet=True, must_be_fresh=True, can_be_prefix=False, lifetime=self.PROP_INTEREST_LIFETIME)
+            int_name, meta_info, content, sig_ptrs = parse_data(pkt)
+            isValidated = await self.secOptions.validate(int_name, sig_ptrs)
+            return StateVector(bytes(content)) if bytes(content) != b'' and isValidated else None
         except (InterestNack, InterestTimeout, InterestCanceled, ValidationFailure):
             SVSyncLogger.info(f'SVSyncBalancer: failed to get {Name.to_str(name)}')
             return None
