@@ -12,7 +12,7 @@ from ndn.encoding import Component, Name
 # Custom Imports
 from .meta_data import MetaData
 from .missing_data import MissingData
-from .state_vector import StateVector, StateVectorComponentModel
+from .state_vector import StateVector, StateVectorEntry
 
 # Class Type: a class
 # Class Purpose:
@@ -23,14 +23,14 @@ class StateTable:
         self.table, self.meta, self.parts = StateVector(), MetaData(), [[0,0]]
         self.meta.source = Name.to_str(mynid).encode()
     def processStateVector(self, incoming_sv:StateVector, oldData:bool) -> List[MissingData]:
-        listOrder:List[StateVectorComponentModel] = incoming_sv.list() if oldData else reversed(incoming_sv.list())
+        listOrder:List[StateVectorEntry] = incoming_sv.list() if oldData else reversed(incoming_sv.list())
         missingList:List[MissingData] = []
         for i in listOrder:
-            tableSeqno:int = self.table.get(bytes(i.nid).decode()) if self.table.get(bytes(i.nid).decode()) else 0
+            tableSeqno:int = self.table.get(i.nid) if self.table.get(i.nid) else 0
             if tableSeqno < i.seqno:
                 tableSeqno = tableSeqno + 1
-                temp:MissingData = MissingData(bytes(i.nid).decode(), tableSeqno, i.seqno)
-                self.table.set(bytes(i.nid).decode(), i.seqno, oldData)
+                temp:MissingData = MissingData(i.nid, tableSeqno, i.seqno)
+                self.table.set(i.nid, i.seqno, oldData)
                 missingList.append(temp)
         return missingList
     def updateMetaData(self) -> None:
