@@ -32,7 +32,7 @@ class SVSyncShared(SVSyncBase):
         while retries+1 > 0:
             try:
                 SVSyncLogger.info(f'SVSync: fetching data {Name.to_str(name)}')
-                _, _, _, pkt = await self.app.express_interest(name, need_raw_packet=True, must_be_fresh=True, can_be_prefix=False, lifetime=2000)
+                _, _, _, pkt = await self.app.express_interest(name, need_raw_packet=True, must_be_fresh=True, can_be_prefix=False, lifetime=self.DATA_INTEREST_LIFETIME)
                 ex_int_name, meta_info, content, sig_ptrs = parse_data(pkt)
                 isValidated = await self.secOptions.validate(ex_int_name, sig_ptrs)
                 if not isValidated:
@@ -57,7 +57,7 @@ class SVSyncShared(SVSyncBase):
                 SVSyncLogger.info("SVSync: retrying fetching data")
         return (None, None)
     def getDataName(self, nid:Name, seqno:int) -> Name:
-        return (self.groupPrefix + [Component.from_str("data")] + nid + Name.from_str(str(seqno)))
+        return ( self.groupPrefix + [Component.from_str("data")] + nid + [Component.from_str(str(seqno))] )
     def serveDataPacket(datapkt:BinaryStr) -> None:
         name, _, content, _ = parse_data(datapkt)
         if content:
